ChatResult class

Result of handling a chat request

Constructors

ChatResult({Map<String, dynamic>? metadata, ChatErrorDetails? errorDetails})

Properties

errorDetails ChatErrorDetails?
final
hashCode int
The hash code for this object.
no setterinherited
metadata Map<String, dynamic>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited