McpServerToolPolicy class
Per-tool permission policy for a remote MCP server. Mirrors
McpServerToolPolicy (permission_policy is snake_case on the wire).
Constructors
- McpServerToolPolicy({required String name, required String permissionPolicy})
-
McpServerToolPolicy.fromJson(Map<
String, dynamic> json) -
Parses from wire JSON.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
The tool name.
final
- permissionPolicy → String
-
always_allow|always_ask|always_deny.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Serializes to wire JSON.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited