McpStdioServerConfig class final

A stdio MCP server. Mirrors McpStdioServerConfig.

Inheritance

Constructors

McpStdioServerConfig({required String command, List<String>? args, Map<String, String>? env, bool? alwaysLoad})
McpStdioServerConfig.fromJson(Map<String, dynamic> json)
Parses from wire JSON.
factory

Properties

alwaysLoad bool?
Whether the server's tools are always loaded (never deferred).
final
args List<String>?
Command arguments.
final
command String
The command to spawn.
final
env Map<String, String>?
Environment overrides for the spawned process.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
The server type discriminator.
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes to wire JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited