SkillsList class final

An explicit list of skill names.

Inheritance

Constructors

SkillsList(List<String> names)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
names List<String>
The enabled skill names.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
toWire() Object
Serializes to the SDK wire value (a list or the string 'all').
override

Operators

operator ==(Object other) bool
The equality operator.
inherited